==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/ImageTilesReadyEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ImageTilesReadyEventArgsDescription } from "./ImageTilesReadyEventArgsDescription";
/**
 * @hidden
 */
var ImageTilesReadyEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ImageTilesReadyEventArgsDescriptionMetadata, _super);
    function ImageTilesReadyEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ImageTilesReadyEventArgsDescriptionMetadata.b = function (a) {
        if (ImageTilesReadyEventArgsDescriptionMetadata.a == null) {
            ImageTilesReadyEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ImageTilesReadyEventArgsDescriptionMetadata.c(ImageTilesReadyEventArgsDescriptionMetadata.a);
        }
        if (a.g(ImageTilesReadyEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(ImageTilesReadyEventArgsDescriptionMetadata.a);
    };
    ImageTilesReadyEventArgsDescriptionMetadata.c = function (a) {
    };
    ImageTilesReadyEventArgsDescriptionMetadata.d = function (a) {
        ImageTilesReadyEventArgsDescriptionMetadata.b(a);
        a.u("ImageTilesReadyEventArgs", function () { return new ImageTilesReadyEventArgsDescription(); });
        a.t("ImageTilesReadyEventArgs", ImageTilesReadyEventArgsDescriptionMetadata.a);
    };
    ImageTilesReadyEventArgsDescriptionMetadata.$t = markType(ImageTilesReadyEventArgsDescriptionMetadata, 'ImageTilesReadyEventArgsDescriptionMetadata');
    ImageTilesReadyEventArgsDescriptionMetadata.a = null;
    return ImageTilesReadyEventArgsDescriptionMetadata;
}(Base));
export { ImageTilesReadyEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/ImageTilesReadyEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ImageTilesReadyEventArgsDescription } from "./ImageTilesReadyEventArgsDescription";
/**
 * @hidden
 */
var ImageTilesReadyEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ImageTilesReadyEventArgsDescriptionMetadata, _super);
    function ImageTilesReadyEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ImageTilesReadyEventArgsDescriptionMetadata.b = function (a) {
        if (ImageTilesReadyEventArgsDescriptionMetadata.a == null) {
            ImageTilesReadyEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ImageTilesReadyEventArgsDescriptionMetadata.c(ImageTilesReadyEventArgsDescriptionMetadata.a);
        }
        if (a.j(ImageTilesReadyEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(ImageTilesReadyEventArgsDescriptionMetadata.a);
    };
    ImageTilesReadyEventArgsDescriptionMetadata.c = function (a) {
    };
    ImageTilesReadyEventArgsDescriptionMetadata.d = function (a) {
        ImageTilesReadyEventArgsDescriptionMetadata.b(a);
        a.aa("ImageTilesReadyEventArgs", function () { return new ImageTilesReadyEventArgsDescription(); });
        a.z("ImageTilesReadyEventArgs", ImageTilesReadyEventArgsDescriptionMetadata.a);
    };
    ImageTilesReadyEventArgsDescriptionMetadata.$t = markType(ImageTilesReadyEventArgsDescriptionMetadata, 'ImageTilesReadyEventArgsDescriptionMetadata');
    ImageTilesReadyEventArgsDescriptionMetadata.a = null;
    return ImageTilesReadyEventArgsDescriptionMetadata;
}(Base));
export { ImageTilesReadyEventArgsDescriptionMetadata };
